[uClibc-cvs] uClibc/libc/sysdeps/linux/alpha/bits kernel_stat.h,1.2,1.3

Erik Andersen andersen at codepoet.org
Fri Jan 24 11:44:34 UTC 2003


Update of /var/cvs/uClibc/libc/sysdeps/linux/alpha/bits
In directory winder:/tmp/cvs-serv18234/libc/sysdeps/linux/alpha/bits

Modified Files:
	kernel_stat.h 
Log Message:
Ok, people are probably going to hate me for this...  This commit changes the
type of 'struct stat' and 'struct stat64' so they use consistant types.  

This change is the result of a bug I found while trying to use GNU tar.  The
problem was caused by our using kernel types within struct stat and trying to
directly compare these values with standard types.  Trying an 'if (a < b)' when
'a' is an 'unsigned long' and 'b' is an 'int' leads to very different results
then when comparing entities of the same type (i.e. time_t values)....
Grumble.  Nasty stuff, but I'm glad I got this out of the way now.

As a result of this fix, uClibc 0.9.17 will not be binary compatible with
earlier releases.  I have always warned people this can and will happen.
 -Erik


Index: kernel_stat.h
===================================================================
RCS file: /var/cvs/uClibc/libc/sysdeps/linux/alpha/bits/kernel_stat.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- kernel_stat.h	25 Aug 2002 00:22:16 -0000	1.2
+++ kernel_stat.h	24 Jan 2003 11:44:00 -0000	1.3
@@ -2,9 +2,9 @@
 #define _BITS_STAT_STRUCT_H
 
 /* This file provides whatever this particular arch's kernel thinks 
  * struct stat should look like...  It turns out each arch has a 
  * different opinion on the subject... */
-struct stat {
+struct kernel_stat {
 	unsigned int	st_dev;
 	unsigned int	st_ino;
 	unsigned int	st_mode;
@@ -21,7 +21,7 @@
 	unsigned int	st_flags;
 	unsigned int	st_gen;
 };
-struct stat64 {
+struct kernel_stat64 {
 	unsigned int	st_dev;
 	unsigned int	st_ino;
 	unsigned int	st_mode;
@@ -2,9 +2,9 @@
 
 /* This file provides whatever this particular arch's kernel thinks 
- * struct stat should look like...  It turns out each arch has a 
+ * struct kernel_stat should look like...  It turns out each arch has a 
  * different opinion on the subject... */




More information about the uClibc-cvs mailing list